==> pygame-2.0.0.tar.gz: pygame-2.0.0/src_c/doc/color_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMECOLOR "Color(r, g, b) -> Color\nColor(r, g, b, a=255) -> Color\nColor(color_value) -> Color\npygame object for color representations"
#define DOC_COLORR "r -> int\nGets or sets the red value of the Color."
#define DOC_COLORG "g -> int\nGets or sets the green value of the Color."
#define DOC_COLORB "b -> int\nGets or sets the blue value of the Color."
#define DOC_COLORA "a -> int\nGets or sets the alpha value of the Color."
#define DOC_COLORCMY "cmy -> tuple\nGets or sets the CMY representation of the Color."
#define DOC_COLORHSVA "hsva -> tuple\nGets or sets the HSVA representation of the Color."
#define DOC_COLORHSLA "hsla -> tuple\nGets or sets the HSLA representation of the Color."
#define DOC_COLORI1I2I3 "i1i2i3 -> tuple\nGets or sets the I1I2I3 representation of the Color."
#define DOC_COLORNORMALIZE "normalize() -> tuple\nReturns the normalized RGBA values of the Color."
#define DOC_COLORCORRECTGAMMA "correct_gamma (gamma) -> Color\nApplies a certain gamma value to the Color."
#define DOC_COLORSETLENGTH "set_length(len) -> None\nSet the number of elements in the Color to 1,2,3, or 4."
#define DOC_COLORLERP "lerp(Color, float) -> Color\nreturns a linear interpolation to the given Color."
#define DOC_COLORPREMULALPHA "premul_alpha() -> Color\nreturns a Color where the r,g,b components have been multiplied by the alpha."


/* Docs in a comment... slightly easier to read. */

/*

pygame.Color
 Color(r, g, b) -> Color
 Color(r, g, b, a=255) -> Color
 Color(color_value) -> Color
pygame object for color representations

pygame.Color.r
 r -> int
Gets or sets the red value of the Color.

pygame.Color.g
 g -> int
Gets or sets the green value of the Color.

pygame.Color.b
 b -> int
Gets or sets the blue value of the Color.

pygame.Color.a
 a -> int
Gets or sets the alpha value of the Color.

pygame.Color.cmy
 cmy -> tuple
Gets or sets the CMY representation of the Color.

pygame.Color.hsva
 hsva -> tuple
Gets or sets the HSVA representation of the Color.

pygame.Color.hsla
 hsla -> tuple
Gets or sets the HSLA representation of the Color.

pygame.Color.i1i2i3
 i1i2i3 -> tuple
Gets or sets the I1I2I3 representation of the Color.

pygame.Color.normalize
 normalize() -> tuple
Returns the normalized RGBA values of the Color.

pygame.Color.correct_gamma
 correct_gamma (gamma) -> Color
Applies a certain gamma value to the Color.

pygame.Color.set_length
 set_length(len) -> None
Set the number of elements in the Color to 1,2,3, or 4.

pygame.Color.lerp
 lerp(Color, float) -> Color
returns a linear interpolation to the given Color.

pygame.Color.premul_alpha
 premul_alpha() -> Color
returns a Color where the r,g,b components have been multiplied by the alpha.

*/

==> pygame-2.0.3.tar.gz: pygame-2.0.3/src_c/doc/color_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMECOLOR "Color(r, g, b) -> Color\nColor(r, g, b, a=255) -> Color\nColor(color_value) -> Color\npygame object for color representations"
#define DOC_COLORR "r -> int\nGets or sets the red value of the Color."
#define DOC_COLORG "g -> int\nGets or sets the green value of the Color."
#define DOC_COLORB "b -> int\nGets or sets the blue value of the Color."
#define DOC_COLORA "a -> int\nGets or sets the alpha value of the Color."
#define DOC_COLORCMY "cmy -> tuple\nGets or sets the CMY representation of the Color."
#define DOC_COLORHSVA "hsva -> tuple\nGets or sets the HSVA representation of the Color."
#define DOC_COLORHSLA "hsla -> tuple\nGets or sets the HSLA representation of the Color."
#define DOC_COLORI1I2I3 "i1i2i3 -> tuple\nGets or sets the I1I2I3 representation of the Color."
#define DOC_COLORNORMALIZE "normalize() -> tuple\nReturns the normalized RGBA values of the Color."
#define DOC_COLORCORRECTGAMMA "correct_gamma (gamma) -> Color\nApplies a certain gamma value to the Color."
#define DOC_COLORSETLENGTH "set_length(len) -> None\nSet the number of elements in the Color to 1,2,3, or 4."
#define DOC_COLORLERP "lerp(Color, float) -> Color\nreturns a linear interpolation to the given Color."
#define DOC_COLORPREMULALPHA "premul_alpha() -> Color\nreturns a Color where the r,g,b components have been multiplied by the alpha."
#define DOC_COLORUPDATE "update(r, g, b) -> None\nupdate(r, g, b, a=255) -> None\nupdate(color_value) -> None\nSets the elements of the color"


/* Docs in a comment... slightly easier to read. */

/*

pygame.Color
 Color(r, g, b) -> Color
 Color(r, g, b, a=255) -> Color
 Color(color_value) -> Color
pygame object for color representations

pygame.Color.r
 r -> int
Gets or sets the red value of the Color.

pygame.Color.g
 g -> int
Gets or sets the green value of the Color.

pygame.Color.b
 b -> int
Gets or sets the blue value of the Color.

pygame.Color.a
 a -> int
Gets or sets the alpha value of the Color.

pygame.Color.cmy
 cmy -> tuple
Gets or sets the CMY representation of the Color.

pygame.Color.hsva
 hsva -> tuple
Gets or sets the HSVA representation of the Color.

pygame.Color.hsla
 hsla -> tuple
Gets or sets the HSLA representation of the Color.

pygame.Color.i1i2i3
 i1i2i3 -> tuple
Gets or sets the I1I2I3 representation of the Color.

pygame.Color.normalize
 normalize() -> tuple
Returns the normalized RGBA values of the Color.

pygame.Color.correct_gamma
 correct_gamma (gamma) -> Color
Applies a certain gamma value to the Color.

pygame.Color.set_length
 set_length(len) -> None
Set the number of elements in the Color to 1,2,3, or 4.

pygame.Color.lerp
 lerp(Color, float) -> Color
returns a linear interpolation to the given Color.

pygame.Color.premul_alpha
 premul_alpha() -> Color
returns a Color where the r,g,b components have been multiplied by the alpha.

pygame.Color.update
 update(r, g, b) -> None
 update(r, g, b, a=255) -> None
 update(color_value) -> None
Sets the elements of the color

*/
